@@ -23,7 +23,7 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/lib/Xmu/EditresCom.c,v 1.23 2006/01/09 14:59:16 dawes Exp $ */
+/* $XFree86: xc/lib/Xmu/EditresCom.c,v 1.24 2007/04/09 15:37:12 tsi Exp $ */
 
 /*
  * Author:  Chris D. Peterson, Dave Sternlicht, MIT X Consortium
@@ -277,7 +277,7 @@ BuildEvent(Widget w, Atom sel, XtPointer data, ResIdent ident,
 {
   EditresEvent *event;
     ProtocolStream alloc_stream, *stream;
-    unsigned char temp;
+    unsigned char temp = 0;
     register unsigned int i;
 
   stream = &alloc_stream;
