@@ -1,6 +1,6 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/ati/atimode.c,v 1.25 2006/01/05 18:55:30 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/ati/atimode.c,v 1.28 2008/01/01 00:40:00 tsi Exp $ */
 /*
- * Copyright 2000 through 2006 by Marc Aurele La France (TSI @ UQV), tsi@xfree86.org
+ * Copyright 2000 through 2008 by Marc Aurele La France (TSI @ UQV), tsi@xfree86.org
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -54,8 +54,14 @@ ATICopyVGAMemory
 
     for (iBank = 0;  iBank < pATIHW->nBank;  iBank++)
     {
+        int i = 0x00010000;
+        volatile CARD8 *t = *to, *f = *from;
+
         (*pATIHW->SetBank)(pATI, iBank);
-        (void)memcpy(*to, *from, 0x00010000U);
+
+        while (--i >= 0)
+            *(t++) = *(f++);
+
         *saveptr = (char *)(*saveptr) + 0x00010000U;
     }
 }
