@@ -44,7 +44,7 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
 ******************************************************************/
-/* $XFree86: xc/programs/lbxproxy/di/utils.c,v 1.20 2006/01/09 15:00:45 dawes Exp $ */
+/* $XFree86: xc/programs/lbxproxy/di/utils.c,v 1.21 2006/12/10 15:58:33 tsi Exp $ */
 
 #include "lbx.h"
 #include <stdio.h>
@@ -95,10 +95,8 @@ static Bool Must_have_memory = FALSE;
 /*
  * Debug stuff
  */
-#ifdef DEBUG
-#ifndef SPECIAL_MALLOC
-#define MEMBUG
-#endif
+#ifdef SPECIAL_MALLOC
+#undef MEMBUG
 #endif
 
 #ifdef MEMBUG
